@@ -1,27 +1,22 @@
 # list
-branches = gl.project_branches.list(project_id=1)
-# or
 branches = project.branches.list()
 # end list
 
 # get
-branch = gl.project_branches.get(project_id=1, id='master')
-# or
 branch = project.branches.get('master')
 # end get
 
 # create
-branch = gl.project_branches.create({'branch_name': 'feature1',
-                                     'ref': 'master'},
-                                    project_id=1)
-# or
+# v4
+branch = project.branches.create({'branch': 'feature1',
+                                  'ref': 'master'})
+
+#v3
 branch = project.branches.create({'branch_name': 'feature1',
                                   'ref': 'master'})
 # end create
 
 # delete
-gl.project_branches.delete(project_id=1, id='feature1')
-# or
 project.branches.delete('feature1')
 # or
 branch.delete()
@@ -31,3 +26,21 @@ branch.delete()
 branch.protect()
 branch.unprotect()
 # end protect
+
+# p_branch list
+p_branches = project.protectedbranches.list()
+# end p_branch list
+
+# p_branch get
+p_branch = project.protectedbranches.get('master')
+# end p_branch get
+
+# p_branch create
+p_branch = project.protectedbranches.create({'name': '*-stable'})
+# end p_branch create
+
+# p_branch delete
+project.protectedbranches.delete('*-stable')
+# or
+p_branch.delete()
+# end p_branch delete
