@@ -55,16 +55,24 @@ commit = gl.project_commits.get(commit_sha, project_id=1)
 builds = commit.builds()
 # end commit list
 
-# get
+# pipeline list get
+# v4 only
+project = gl.projects.get(project_id)
+pipeline = project.pipelines.get(pipeline_id)
+jobs = pipeline.jobs.list()  # gets all jobs in pipeline
+job = pipeline.jobs.get(job_id)  # gets one job from pipeline
+# end pipeline list get
+
+# get job
 project.builds.get(build_id)  # v3
 project.jobs.get(job_id)  # v4
-# end get
+# end get job
 
 # artifacts
 build_or_job.artifacts()
 # end artifacts
 
-# stream artifacts
+# stream artifacts with class
 class Foo(object):
     def __init__(self):
         self._fd = open('artifacts.zip', 'wb')
@@ -75,7 +83,15 @@ class Foo(object):
 target = Foo()
 build_or_job.artifacts(streamed=True, action=target)
 del(target)  # flushes data on disk
-# end stream artifacts
+# end stream artifacts with class
+
+# stream artifacts with unzip
+zipfn = "___artifacts.zip"
+with open(zipfn, "wb") as f:
+    build_or_job.artifacts(streamed=True, action=f.write)
+subprocess.run(["unzip", "-bo", zipfn])
+os.unlink(zipfn)
+# end stream artifacts with unzip
 
 # keep artifacts
 build_or_job.keep_artifacts()
