@@ -28,6 +28,10 @@ issues = project.issues.list(order_by='created_at', sort='desc')
 issue = project.issues.get(issue_id)
 # end project issues get
 
+# project issues get from iid
+issue = project.issues.list(iid=issue_iid)[0]
+# end project issues get from iid
+
 # project issues create
 issue = project.issues.create({'title': 'I have a bug',
                                'description': 'Something useful here.'})
@@ -85,3 +89,7 @@ issue.add_time_spent({'duration': '3h30m'})
 # project issue reset time spent
 issue.reset_time_spent()
 # end project issue reset time spent
+
+# project issue useragent
+detail = issue.user_agent_detail()
+# end project issue useragent
