@@ -33,6 +33,7 @@ project = gl.projects.create({'name': 'project1'})
 # user create
 alice = gl.users.list(username='alice')[0]
 user_project = alice.projects.create({'name': 'project'})
+user_projects = alice.projects.list()
 # end user create
 
 # update
@@ -68,12 +69,6 @@ project.archive()
 project.unarchive()
 # end archive
 
-# events list
-gl.project_events.list(project_id=1)
-# or
-project.events.list()
-# end events list
-
 # members list
 members = project.members.list()
 # end members list
@@ -229,7 +224,7 @@ tags = project.tags.list()
 # end tags list
 
 # tags get
-tags = project.tags.list('1.0')
+tag = project.tags.get('1.0')
 # end tags get
 
 # tags create
@@ -326,26 +321,6 @@ service.save()
 service.delete()
 # end service delete
 
-# pipeline list
-pipelines = project.pipelines.list()
-# end pipeline list
-
-# pipeline get
-pipeline = project.pipelines.get(pipeline_id)
-# end pipeline get
-
-# pipeline create
-pipeline = project.pipelines.create({'ref': 'master'})
-# end pipeline create
-
-# pipeline retry
-pipeline.retry()
-# end pipeline retry
-
-# pipeline cancel
-pipeline.cancel()
-# end pipeline cancel
-
 # boards list
 boards = project.boards.list()
 # end boards list
