@@ -24,19 +24,13 @@ runner.delete()
 # end delete
 
 # project list
-runners = gl.project_runners.list(project_id=1)
-# or
 runners = project.runners.list()
 # end project list
 
 # project enable
-p_runner = gl.project_runners.create({'runner_id': runner.id}, project_id=1)
-# or
 p_runner = project.runners.create({'runner_id': runner.id})
 # end project enable
 
 # project disable
-gl.project_runners.delete(runner.id)
-# or
 project.runners.delete(runner.id)
 # end project disable
