@@ -34,11 +34,11 @@ from gitlab.exceptions import *  # noqa
 from gitlab.v3.objects import *  # noqa
 
 __title__ = 'python-gitlab'
-__version__ = '1.2.0'
+__version__ = '1.3.0'
 __author__ = 'Gauvain Pocentek'
 __email__ = 'gauvain@pocentek.net'
 __license__ = 'LGPL3'
-__copyright__ = 'Copyright 2013-2017 Gauvain Pocentek'
+__copyright__ = 'Copyright 2013-2018 Gauvain Pocentek'
 
 warnings.filterwarnings('default', category=DeprecationWarning,
                         module='^gitlab')
@@ -73,7 +73,7 @@ class Gitlab(object):
 
     def __init__(self, url, private_token=None, oauth_token=None, email=None,
                  password=None, ssl_verify=True, http_username=None,
-                 http_password=None, timeout=None, api_version='3',
+                 http_password=None, timeout=None, api_version='4',
                  session=None):
 
         self._api_version = str(api_version)
@@ -125,6 +125,7 @@ class Gitlab(object):
             self.teams = objects.TeamManager(self)
         else:
             self.dockerfiles = objects.DockerfileManager(self)
+            self.events = objects.EventManager(self)
             self.features = objects.FeatureManager(self)
             self.pagesdomains = objects.PagesDomainManager(self)
             self.user_activities = objects.UserActivitiesManager(self)
@@ -146,6 +147,12 @@ class Gitlab(object):
                     manager = getattr(objects, cls_name)(self)
                     setattr(self, var_name, manager)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args):
+        self.session.close()
+
     def __getstate__(self):
         state = self.__dict__.copy()
         state.pop('_objects')
