@@ -21,14 +21,8 @@ DEPLOY_KEY = ("ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDFdRyjJQh+1niBpXqE2I8dzjG"
               "rke9IepE7SPBT41C+YtUX4dfDZDmczM1cE0YL/krdUCfuZHMa4ZS2YyNd6slufc"
               "vn bar@foo")
 
-# login/password authentication
-gl = gitlab.Gitlab('http://localhost:8080', email=LOGIN, password=PASSWORD)
-gl.auth()
-token_from_auth = gl.private_token
-
 # token authentication from config file
 gl = gitlab.Gitlab.from_config(config_files=['/tmp/python-gitlab.cfg'])
-assert(token_from_auth == gl.private_token)
 gl.auth()
 assert(isinstance(gl.user, gitlab.v3.objects.CurrentUser))
 
@@ -105,7 +99,7 @@ p_id = gl.groups.search('group2')[0].id
 group3 = gl.groups.create({'name': 'group3', 'path': 'group3', 'parent_id': p_id})
 
 assert(len(gl.groups.list()) == 3)
-assert(len(gl.groups.search("1")) == 1)
+assert(len(gl.groups.search("oup1")) == 1)
 assert(group3.parent_id == p_id)
 
 group1.members.create({'access_level': gitlab.Group.OWNER_ACCESS,
