@@ -92,6 +92,12 @@ assert(new_user.email == user.email)
 new_user.block()
 new_user.unblock()
 
+# user projects list
+assert(len(new_user.projects.list()) == 0)
+
+# events list
+new_user.events.list()
+
 foobar_user = gl.users.create(
     {'email': 'foobar@example.com', 'username': 'foobar',
      'name': 'Foo Bar', 'password': 'foobar_password'})
@@ -405,7 +411,7 @@ assert(env.external_url == 'http://new.env/whatever')
 env.delete()
 assert(len(admin_project.environments.list()) == 0)
 
-# events
+# project events
 admin_project.events.list()
 
 # forks
@@ -527,6 +533,12 @@ admin_project.files.create({'file_path': 'README2.rst',
 mr = admin_project.mergerequests.create({'source_branch': 'branch1',
                                          'target_branch': 'master',
                                          'title': 'MR readme2'})
+
+# basic testing: only make sure that the methods exist
+mr.commits()
+mr.changes()
+#mr.participants()  # not yet available
+
 mr.merge()
 admin_project.branches.delete('branch1')
 
@@ -631,3 +643,6 @@ snippet.delete()
 
 # user activities
 gl.user_activities.list()
+
+# events
+gl.events.list()
